# Spelling words like AI


This project is inspired from a popular meme which consisted of will AI systems count numbers. For eg:

1999 - Nineteen Ninty Nine

1888 - Eighteen Eighty Eight

1111 - Eleven Eleven,

No guys, AI is more cooler. It's  => **Oneteen Onety One**

This actually is one of the Rules of Machine Learning, ie 

Rule #7: Turn heuristics into features, or handle them externally.

[Source](https://developers.google.com/machine-learning/guides/rules-of-ml)
